@@ -8,7 +8,6 @@ PROGRAM = 'Xvfb'
 URL = None
 PACKAGE = 'xvfb'
 
-EasyProcess([PROGRAM, '-help'], url=URL, ubuntu_package=PACKAGE).check_installed()
 
 class XvfbDisplay(AbstractDisplay):
     '''
@@ -29,6 +28,10 @@ class XvfbDisplay(AbstractDisplay):
         self.bgcolor = bgcolor
         self.display = None
         
+    @classmethod
+    def check_installed(cls):
+        EasyProcess([PROGRAM, '-help'], url=URL, ubuntu_package=PACKAGE).check_installed()
+        
     @property
     def cmd(self):
         cmd = [PROGRAM ,
